"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const messages_1 = require("@cucumber/messages");
class AstMaker {
    makeGherkinDocument(uri, feature) {
        return messages_1.messages.GherkinDocument.create({
            uri,
            feature,
        });
    }
    makeFeature(line, keyword, name, description, children, tags) {
        return messages_1.messages.GherkinDocument.Feature.create({
            location: messages_1.messages.Location.create({ line }),
            keyword,
            name,
            description,
            children: children.map((child) => child),
            tags: tags ? tags.map((tag) => tag) : undefined,
        });
    }
    makeTag(name, line) {
        return messages_1.messages.GherkinDocument.Feature.Tag.create({
            name,
            location: messages_1.messages.Location.create({ line }),
        });
    }
    makeScenarioFeatureChild(id, line, keyword, name, description, steps, tags) {
        return messages_1.messages.GherkinDocument.Feature.FeatureChild.create({
            scenario: messages_1.messages.GherkinDocument.Feature.Scenario.create({
                id,
                location: messages_1.messages.Location.create({ line }),
                keyword,
                name,
                description,
                steps: steps.map((step) => step),
                tags: tags ? tags.map((tag) => tag) : undefined,
            }),
        });
    }
    makeBackgroundFeatureChild(line, keyword, name, description, steps) {
        return messages_1.messages.GherkinDocument.Feature.FeatureChild.create({
            background: messages_1.messages.GherkinDocument.Feature.Background.create({
                location: messages_1.messages.Location.create({ line }),
                keyword,
                name,
                description,
                steps: steps.map((step) => step),
            }),
        });
    }
    makeStep(id, line, keyword, text, docString, dataTable) {
        return messages_1.messages.GherkinDocument.Feature.Step.create({
            id,
            location: messages_1.messages.Location.create({ line }),
            keyword,
            text,
            docString,
            dataTable,
        });
    }
    makeDocstring(mediaType, content) {
        return messages_1.messages.GherkinDocument.Feature.Step.DocString.create({
            mediaType,
            content,
        });
    }
    makeDataTable(cells) {
        return messages_1.messages.GherkinDocument.Feature.Step.DataTable.create({
            rows: cells.map((row) => messages_1.messages.GherkinDocument.Feature.TableRow.create({
                cells: row.map((cell) => messages_1.messages.GherkinDocument.Feature.TableRow.TableCell.create({
                    value: cell,
                })),
            })),
        });
    }
}
exports.default = AstMaker;
//# sourceMappingURL=AstMaker.js.map