"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PredictableHookTestStep = exports.PredictablePickleTestStep = void 0;
const messages_1 = require("@cucumber/messages");
const fake_cucumber_1 = require("@cucumber/fake-cucumber");
const fake_cucumber_2 = require("@cucumber/fake-cucumber");
class PredictableTestStep extends fake_cucumber_1.TestStep {
    constructor(id, sourceId, alwaysExecute, status, duration, errorMessage) {
        // TODO: Rather than injecting a PerfHooksStopwatch here we should inject one that uses duration.
        // That will also require a different API for measuring duration...
        super(id, sourceId, alwaysExecute, [], [], new fake_cucumber_1.DateClock(), new fake_cucumber_2.PerfHooksStopwatch(), null);
        this.id = id;
        this.sourceId = sourceId;
        this.alwaysExecute = alwaysExecute;
        this.status = status;
        this.duration = duration;
        this.errorMessage = errorMessage;
    }
    execute(_, testCaseStartedId, listener) {
        return __awaiter(this, void 0, void 0, function* () {
            this.emitTestStepStarted(testCaseStartedId, listener);
            return this.emitTestStepFinished(testCaseStartedId, new messages_1.messages.TestStepFinished.TestStepResult({
                duration: messages_1.TimeConversion.millisecondsToDuration(this.duration),
                status: this.status,
                message: this.errorMessage,
            }), listener);
        });
    }
}
class PredictablePickleTestStep extends PredictableTestStep {
    constructor(id, sourceId, alwaysExecute, stepDefinitionId, status, duration, errorMessage) {
        super(id, sourceId, alwaysExecute, status, duration, errorMessage);
        this.id = id;
        this.sourceId = sourceId;
        this.alwaysExecute = alwaysExecute;
        this.stepDefinitionId = stepDefinitionId;
    }
    toMessage() {
        const stepDefinitionIds = this.stepDefinitionId ? [this.stepDefinitionId] : [];
        return new messages_1.messages.TestCase.TestStep({
            id: this.id,
            pickleStepId: this.sourceId,
            stepDefinitionIds,
        });
    }
}
exports.PredictablePickleTestStep = PredictablePickleTestStep;
class PredictableHookTestStep extends PredictableTestStep {
    toMessage() {
        const testStep = new messages_1.messages.TestCase.TestStep({
            id: this.id,
            hookId: this.sourceId,
        });
        testStep.pickleStepId = undefined;
        return testStep;
    }
}
exports.PredictableHookTestStep = PredictableHookTestStep;
//# sourceMappingURL=PredictableTestSteps.js.map