"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.traverseDataTable = exports.traverseDocString = exports.traverseStep = exports.traverseElement = exports.traverseFeature = void 0;
const JSONTraverse_1 = require("../cucumber-generic/JSONTraverse");
function durationToMillis(duration) {
    return duration ? duration / 1000000 : 0;
}
function traverseFeature(feature, astMaker, newId, predictableSupportCode) {
    return JSONTraverse_1.traverseFeature(feature, astMaker, newId, predictableSupportCode, traverseElement);
}
exports.traverseFeature = traverseFeature;
function traverseElement(element, astMaker, newId, predictableSupportCode) {
    let child;
    switch (element.type) {
        case 'background':
            child = astMaker.makeBackgroundFeatureChild(element.line, element.keyword, element.name, element.description, element.steps.map((step) => traverseStep(step, astMaker, newId, predictableSupportCode)));
            break;
        case 'scenario': {
            const tags = element.tags ? element.tags.map((tag) => JSONTraverse_1.traverseTag(tag, astMaker)) : undefined;
            child = astMaker.makeScenarioFeatureChild(newId(), element.line, element.keyword, element.name, element.description, element.steps.map((step) => traverseStep(step, astMaker, newId, predictableSupportCode)), tags);
            break;
        }
        default:
            throw new Error(`Unsupported type for feature child: ${element.type}`);
    }
    if (element.before) {
        for (const beforeHook of element.before) {
            predictableSupportCode.addPredictableBeforeHook(beforeHook.match.location, child.scenario.id, beforeHook.result.status, durationToMillis(beforeHook.result.duration), beforeHook.result.error_message);
        }
    }
    if (element.after) {
        for (const afterHook of element.after) {
            predictableSupportCode.addPredictableAfterHook(afterHook.match.location, child.scenario.id, afterHook.result.status, durationToMillis(afterHook.result.duration), afterHook.result.error_message);
        }
    }
    return child;
}
exports.traverseElement = traverseElement;
function traverseStep(step, astMaker, newId, predictableSupportCode) {
    const docString = step.doc_string ? traverseDocString(step.doc_string, astMaker) : null;
    const dataTable = step.rows ? traverseDataTable(step.rows, astMaker) : null;
    const gherkinStep = astMaker.makeStep(newId(), step.line, step.keyword, step.name, docString, dataTable);
    if (gherkinStep && step.match && step.match.location) {
        predictableSupportCode.addPredictableStepDefinition(step.match.location, gherkinStep.id, step.result.status, durationToMillis(step.result.duration), step.result.error_message);
    }
    return gherkinStep;
}
exports.traverseStep = traverseStep;
function traverseDocString(docString, astMaker) {
    return astMaker.makeDocstring(docString.content_type, docString.value);
}
exports.traverseDocString = traverseDocString;
function traverseDataTable(rows, astMaker) {
    return astMaker.makeDataTable(rows.map((row) => row.cells));
}
exports.traverseDataTable = traverseDataTable;
//# sourceMappingURL=JSONTraverse.js.map