"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const src_1 = require("../src");
const messages_1 = require("@cucumber/messages");
const assert_1 = __importDefault(require("assert"));
const package_json_1 = require("../package.json");
const message_streams_1 = require("@cucumber/message-streams");
describe('jsonToMessages', () => {
    it('emits a Source message for every Gherkin document', () => __awaiter(void 0, void 0, void 0, function* () {
        const emitted = yield produceMessages([
            JSON.stringify([
                {
                    elements: [],
                    id: 'hooks',
                    keyword: 'Feature',
                    line: 1,
                    name: 'Hooks',
                    uri: 'features/hooks/hooks.feature',
                },
            ]),
        ]);
        assert_1.default.equal(emitted.filter((envelope) => envelope.source).length, 1);
    }));
    context('a meta Message is emitted at the beginning', () => {
        let meta;
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            const emitted = yield produceMessages(['[]']);
            meta = emitted.find((envelope) => envelope.meta).meta;
        }));
        it('contains the @cucumber-messages version', () => {
            assert_1.default.equal(meta.protocolVersion, messages_1.version);
        });
        it('does not provide any information about the original producer of the JSON', () => {
            assert_1.default.equal(meta.implementation.name, '@cucumber/json-to-messages');
            assert_1.default.equal(meta.implementation.version, package_json_1.version);
        });
    });
});
function produceMessages(jsons) {
    return __awaiter(this, void 0, void 0, function* () {
        const inputStream = new stream_1.Readable({
            read() {
                this.push(jsons.join(''));
                this.push(null);
            },
        });
        const emitted = [];
        const out = new message_streams_1.NdjsonToMessageStream(messages_1.messages.Envelope.fromObject.bind(messages_1.messages.Envelope));
        out.on('data', (message) => emitted.push(message));
        yield src_1.jsonToMessages(inputStream, out);
        return emitted;
    });
}
//# sourceMappingURL=jsonToMessagesTest.js.map