"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = __importDefault(require("assert"));
const makePredictablePickleTestStep_1 = __importDefault(require("../../src/test-generation/makePredictablePickleTestStep"));
const messages_1 = require("@cucumber/messages");
const PredictableStepDefinition_1 = __importDefault(require("../../src/PredictableStepDefinition"));
describe('makePredictablePickleTestStep', () => {
    it('returns a TestStep with status Undefined when there is no matching step', () => __awaiter(void 0, void 0, void 0, function* () {
        const step = makePredictablePickleTestStep_1.default('test-step-id', messages_1.messages.Pickle.PickleStep.create(), []);
        const result = yield step.execute(null, 'some-id', () => null);
        assert_1.default.equal(result.status, messages_1.messages.TestStepFinished.TestStepResult.Status.UNDEFINED);
        assert_1.default.equal(result.duration.seconds, 0);
        assert_1.default.equal(result.duration.nanos, 0);
    }));
    it('returns a TestStep which will take the status of the first matching StepDefinition', () => __awaiter(void 0, void 0, void 0, function* () {
        const step = makePredictablePickleTestStep_1.default('test-step-id', messages_1.messages.Pickle.PickleStep.create({
            astNodeIds: ['some-step-id'],
        }), [
            new PredictableStepDefinition_1.default('some-id', 'some-step-id', 'somewhere', messages_1.messages.TestStepFinished.TestStepResult.Status.SKIPPED, 987654),
        ]);
        const result = yield step.execute(null, 'some-id', () => null);
        assert_1.default.equal(result.status, messages_1.messages.TestStepFinished.TestStepResult.Status.SKIPPED);
        assert_1.default.equal(result.duration.seconds, 987);
        assert_1.default.equal(result.duration.nanos, 654000000);
    }));
    it('correctly sets the error message if existing', () => __awaiter(void 0, void 0, void 0, function* () {
        const step = makePredictablePickleTestStep_1.default('test-step-id', messages_1.messages.Pickle.PickleStep.create({
            astNodeIds: ['some-step-id'],
        }), [
            new PredictableStepDefinition_1.default('some-id', 'some-step-id', 'somewhere', messages_1.messages.TestStepFinished.TestStepResult.Status.FAILED, 987654, 'An error has been raised here'),
        ]);
        const result = yield step.execute(null, 'some-id', () => null);
        assert_1.default.equal(result.message, 'An error has been raised here');
    }));
});
//# sourceMappingURL=makePredictablePickleTestStepTest.js.map